from .advanced_ml_tab import AdvancedMLTabWithFeatureSelection
from .batch_processor_tab import BatchProcessingTab 
from .feature_selection_tab import FeatureSelectionTab